==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkPassInputTypeAlgorithm.java <==
// java wrapper for vtkPassInputTypeAlgorithm object
//

package vtk;
import vtk.*;

public class vtkPassInputTypeAlgorithm extends vtkAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkDataObject GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetOutput_3(int id0);
  public vtkDataObject GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetPolyDataOutput_4();
  public vtkPolyData GetPolyDataOutput() {
    long temp = GetPolyDataOutput_4();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetStructuredPointsOutput_5();
  public vtkStructuredPoints GetStructuredPointsOutput() {
    long temp = GetStructuredPointsOutput_5();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetImageDataOutput_6();
  public vtkImageData GetImageDataOutput() {
    long temp = GetImageDataOutput_6();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetStructuredGridOutput_7();
  public vtkStructuredGrid GetStructuredGridOutput() {
    long temp = GetStructuredGridOutput_7();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetUnstructuredGridOutput_8();
  public vtkUnstructuredGrid GetUnstructuredGridOutput() {
    long temp = GetUnstructuredGridOutput_8();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetRectilinearGridOutput_9();
  public vtkRectilinearGrid GetRectilinearGridOutput() {
    long temp = GetRectilinearGridOutput_9();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetTableOutput_10();
  public vtkTable GetTableOutput() {
    long temp = GetTableOutput_10();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetGraphOutput_11();
  public vtkGraph GetGraphOutput() {
    long temp = GetGraphOutput_11();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetInput_12();
  public vtkDataObject GetInput() {
    long temp = GetInput_12();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetInputData_13(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_13(id0); }

  private native void SetInputData_14(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_14(id0,id1); }

  private native void AddInputData_15(vtkDataObject id0);
  public void AddInputData(vtkDataObject id0)
    { AddInputData_15(id0); }

  private native void AddInputData_16(int id0,vtkDataObject id1);
  public void AddInputData(int id0,vtkDataObject id1)
    { AddInputData_16(id0,id1); }

  public vtkPassInputTypeAlgorithm() { super(); }

  public vtkPassInputTypeAlgorithm(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkPassInputTypeAlgorithm.java <==
// java wrapper for vtkPassInputTypeAlgorithm object
//

package vtk;
import vtk.*;

public class vtkPassInputTypeAlgorithm extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkDataObject GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_3(int id0);
  public vtkDataObject GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPolyDataOutput_4();
  public vtkPolyData GetPolyDataOutput() {
    long temp = GetPolyDataOutput_4();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredPointsOutput_5();
  public vtkStructuredPoints GetStructuredPointsOutput() {
    long temp = GetStructuredPointsOutput_5();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetImageDataOutput_6();
  public vtkImageData GetImageDataOutput() {
    long temp = GetImageDataOutput_6();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredGridOutput_7();
  public vtkStructuredGrid GetStructuredGridOutput() {
    long temp = GetStructuredGridOutput_7();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetUnstructuredGridOutput_8();
  public vtkUnstructuredGrid GetUnstructuredGridOutput() {
    long temp = GetUnstructuredGridOutput_8();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRectilinearGridOutput_9();
  public vtkRectilinearGrid GetRectilinearGridOutput() {
    long temp = GetRectilinearGridOutput_9();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTableOutput_10();
  public vtkTable GetTableOutput() {
    long temp = GetTableOutput_10();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetGraphOutput_11();
  public vtkGraph GetGraphOutput() {
    long temp = GetGraphOutput_11();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_12();
  public vtkDataObject GetInput() {
    long temp = GetInput_12();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInputData_13(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_13(id0); }

  private native void SetInputData_14(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_14(id0,id1); }

  private native void AddInputData_15(vtkDataObject id0);
  public void AddInputData(vtkDataObject id0)
    { AddInputData_15(id0); }

  private native void AddInputData_16(int id0,vtkDataObject id1);
  public void AddInputData(int id0,vtkDataObject id1)
    { AddInputData_16(id0,id1); }

  public vtkPassInputTypeAlgorithm() { super(); }

  public vtkPassInputTypeAlgorithm(long id) { super(id); }
  public native long   VTKInit();

}
